% This file is part of the journal article "Semi-automated statistical 
% discontinuity analyses from scan-line data" 
% Copyright (C) 2022 Christian Zangerl, Thomas Strauhal, Matthias Koppensteiner
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
% GNU General Public License for more details (http://www.gnu.org/licenses/).


% STEP II
% calculation of the angle between the mean set and the scanline orientation
% i.e. calculation of cos(delta)

% The scripts (m-files) are provided "As Is", without warranty of any kind, 
% express or implied, including but not limited to the warranties of 
% merchantability, fitness for a particular purpose and noninfringement. 
% In no event shall the authors be liable for any claim, damages or other 
% liability, whether in an action of contract, tort or otherwise, arising from, 
% out of or in connection with the scripts or the use or other dealings 
% in the scripts.


% load table with scanline orientation and mean set orientation data
% table contain 6 columns: "set number" "scanline number" "scanline trend" 
% "scanline plunge" "mean set dip-direction" "mean set dip-angle"
clear
load "scanline_set_orientation.dat"
Ae=scanline_set_orientation

% calculation of normal to the mean discontinuity sets (i.e. poles)
joint_dip_dir=Ae(:,5)
joint_dip_angle=Ae(:,6)

Bel180=(joint_dip_dir>=180)*(-180)
Abo180=(joint_dip_dir<180)*(+180)
joint_normal_trend=Bel180+Abo180+joint_dip_dir

joint_normal_plunge=90-joint_dip_angle

% include a column of trend and plunge of the set normal (pole)
% colums 7 and 8
Ae(:,7)=joint_normal_trend
Ae(:,8)=joint_normal_plunge

% calculation of cos(delta)
alpa_n=Ae(:,7)
alpa_s=Ae(:,3)
beta_n=Ae(:,8)
beta_s=Ae(:,4)

cos_delta=abs(cosd(alpa_n-alpa_s).*cosd(beta_n).*cosd(beta_s)+sind(beta_n).*sind(beta_s))

% include a column of cos(delta)
% colum 9
Ae(:,9)=cos_delta

% export and save data
data_cos_all=Ae

%selection of discontinuity set to export (e.g. discontinuity set 1 set_n=1)
set_n1=1
set_n2=2
set_n3=3

%search for discontinuity set number 1
find_set1=find(data_cos_all(:,1)==set_n1)
cos_set_1=data_cos_all(find_set1,:)

find_set2=find(data_cos_all(:,1)==set_n2)
cos_set_2=data_cos_all(find_set2,:)

find_set3=find(data_cos_all(:,1)==set_n3)
cos_set_3=data_cos_all(find_set3,:)

%save selection for discontinuity set 1, and 3 in variable
save cos_set1-3.mat