% This file is part of the journal article "Semi-automated statistical 
% discontinuity analyses from scan-line data"
% Copyright (C) 2022 Christian Zangerl, Thomas Strauhal, Matthias Koppensteiner
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
% GNU General Public License for more details (http://www.gnu.org/licenses/).


% STEP IV - spacing_calculation.m
% spacing and frequency calculation
% calculation loop must be done for each discontinuity set
% as an example, it is calculated here for set 1 and 8 scanlines

% -----------------input--------------------------------
% total number of selected scanlines (e.g. n_scan=2)
clear
n_scan=8

% selcetion of scanlines  
% include scanline numbers in the row vector (e.g. l_scan=[1 2 3 4 ...]
% numbers of values in l_scan must be equal to n_scan     
l_scan=[1 3 4 6 9 10 13 15]

% load data-file for each set (e.g. for set 1)
load spacing_set1-3.mat

% define the set number here
% %change to spacing_set1,2,3...
Ae=spacing_set1

% include mean cos(delta) for each selected scanline and joint set
% e.g. change for Set 1,2,3 cos(delta) values - result of Step II
meancosdelta=[0.912140 0.732710 0.088680 0.783051 0.793154 0.180424 0.781008 0.925069]



% ------------------calculation-------------------------
% write mean cos(delta) for each scanline in column 4 
x=0
for x=1 : n_scan
   Dx=l_scan(x)
   Ae(find(Ae(:,2)==Dx),4)=meancosdelta(x)
end

% calculation of cos(delta)*intersection distance
Ae(:,5)=Ae(:,3).*Ae(:,4)

% calculation of the set spacing (Xs) and normal set spacing (Xn)
Xs=[]
Xn=[]
Xssm=[]
Xnnm=[]
j=0
for j=1 : n_scan
Fe=l_scan(j)
Xs=[Xs;diff(Ae(find(Ae(:,2)==Fe),3))];
Xn=[Xn;diff(Ae(find(Ae(:,2)==Fe),5))];

% calculation of the mean set and mean normal set spacing Xss and Xnn for each scanline
Xss=[]
Xss=diff(Ae(find(Ae(:,2)==Fe),3))
Xssm=[Xssm;mean(Xss)];

Xnn=[]
Xnn=diff(Ae(find(Ae(:,2)==Fe),5))
Xnnm=[Xnnm;mean(Xnn)];

end

% output files
% table of set spacing Xs for plotting (e.g. histgram)
set_spacing_table=Xs;

% table of normal set spacing Xn for plotting (e.g. histogram), all data
% mean and standard deviation (mean_spacing_SD), all data
% mean linear frequency (mean_frequency_all), all data
normal_set_spacing_table=Xn;
mean_normal_set_spacing_all=mean(normal_set_spacing_table)
mean_spacing_SD=std(normal_set_spacing_table)
mean_frequency_all=1/mean_normal_set_spacing_all

% table of mean set spacing for each scanline
mean_set_spacing_table=Xssm

% table of mean normal set spacing for each scanline
mean_normal_set_spacing_table=Xnnm

%calculation and table of the mean linear frequency for each scanline
mean_lambda_s=1./Xssm
mean_lambda_n=1./Xnnm

%save variables as mat-file
save set1_spacing_parameters.mat %change to set1,2,3...