% This file is part of the journal article "Semi-automated statistical 
% discontinuity analyses from scan-line data"
% Copyright (C) 2022 Christian Zangerl, Thomas Strauhal, Matthias Koppensteiner
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
% GNU General Public License for more details (http://www.gnu.org/licenses/).


% STEP V - trace_length_calculation
% trace length calculation for each set
% as an example, it is calculated here for set 1 

%---------------------input------------------------------------------
% load trace length data file for each set
% data file structure "discontinuity number" "scanline-number" "trace length above"
% "trace length below" "termination above" "termination below"
clear
load "trace_data_set1.dat" %change to set1,2,3...
trace_data=trace_data_set1 %change to set1,2,3...

% define a curtailment value c, unit in [m], e.g. 3 m
c=3

% histogram range and class interval (e.g. 0 to 5 meter; [0:0.5:5]) 
hist_range=[0:0.5:10]


%----------------calculation------------------------------------------
% Approach I by Priest and Hudson (1981)
% negative exponential distribution, f(l), of full trace lengths
% full trace lengths intersected by the scanline, g(l) i.e. measured
trace_data(:,7)=trace_data(:,3)+trace_data(:,4);
%mygl=mean of g(l), myl1=mean of f(l)
my_gl=mean(trace_data(:,7));
my_L1=0.5*my_gl


% Approach II by Priest (1993)
tt=size(trace_data);
n=tt(:,1);
[r,m]=size(find(trace_data(:,3)<c));
my_L2=c/(-(log(1-(r/n))))


% Approach III by Priest (1993)
% distribution independent
[Nx,bins]=hist(trace_data(:,3),hist_range);
intervall=hist_range(1,2)-hist_range(1,1);
nn=sum(Nx);
bar(bins,Nx)
[p,s]=polyfit(bins,Nx,6);
Nx0=polyval(p,0);
my_L3=1/(Nx0/(nn*intervall))


% Approach IV by Laslett (1982)
% trace length after Laslett assuming a neg. exp. distribution
% 1..not visible, 2..intact rock, 3..another joint
trace_data(:,8)=trace_data(:,5).*trace_data(:,6);

% no ends observable
nzk=find(trace_data(:,8)==1);
% one end observable
nyj=find(trace_data(:,8)==2 | trace_data(:,8)==3);
% two ends observable
nxi=find(trace_data(:,8)>3);

[nnn,rt]=size(nxi);
[m,tr]=size(nyj);

my_L4=(sum(trace_data(nxi,7))+sum(trace_data(nyj,7))+sum(trace_data(nzk,7)))/(2*nnn+m)


% calculation of termination index
% 1..termination is not visible, 2..termination at intact rock, 
% 3..termination at another discontinuity
% above
Niab=find(trace_data(:,5)==2);
[Nia,bi]=size(Niab);
Naab=find(trace_data(:,5)==3);
[Naa,ba]=size(Naab);
Noab=find(trace_data(:,5)==1);
[Noa,bo]=size(Noab);

% below
Nibe=find(trace_data(:,6)==2);
[Nib,be]=size(Nibe);
Nabe=find(trace_data(:,6)==3);
[Nab,bf]=size(Nabe);
Nobe=find(trace_data(:,6)==1);
[Nob,bg]=size(Nobe);

% all semi-traces
Ni_all=Nia+Nib; %2..intact rock
Na_all=Naa+Nab; %3..another discontinuity
No_all=Noa+Nob; %1..not visible

% termination based on semi-traces above the scanline
termination_above=(100*Nia)/(Nia+Naa+Noa)
% termination based on semi-traces below the scanline
termination_below=(100*Nib)/(Nib+Nab+Nob)
% termination based on all semi-traces
termination_all=(100*Ni_all)/(Ni_all+Na_all+No_all)

% save data to mat-file
% change trace_termination_set1.mat ...replace 1 by 2,3
save trace_termination_set1.mat