% This file is part of the journal article "Semi-automated statistical 
% discontinuity analyses from scan-line data"
% Copyright (C) 2022 Christian Zangerl, Thomas Strauhal, Matthias Koppensteiner
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
% GNU General Public License for more details (http://www.gnu.org/licenses/).


% STEP VI - spacing
% plot normal set spacing histogram with fitted neg. exp. function
% as an example, it is calculated here for set 1
% load Octave statistics package
pkg load statistics

% ---------------------------input--------------------------------
% load data to plot
% load data file set1_spacing_parameters.mat replace 1 by 2 or 3
clear
load set1_spacing_parameters.mat

% define the histogram range and size in [m]
% e.g.[0.1:0.2:2] range from 0 to 2 m, class interval equals 0.2 m 
delta=[0.1:0.2:2]

% --------calculation--------------------------------------
% calculate values for the histogram
[Nx,xhist]=hist(normal_set_spacing_table,delta)
int=delta(:,2)-delta(:,1)
ngem=sum(Nx)
fxgem=Nx/(ngem*int)
bar(xhist,Nx)

% fit negative exponential function to the histogram
% plot range - same as histogramm e.g. 0 to 2 m, interval 0.05 m 
spacing_x_axis=[0:0.05:2]

%mean of neg.exp.function
my=mean(normal_set_spacing_table)
fun_neg_exp=(1/my)*exp(-spacing_x_axis/my)

% plot histogram and neg.exp.function
bar(xhist,fxgem)
hold on
grid on
plot(spacing_x_axis,fun_neg_exp,"linewidth",2)
xlabel ("Normal set spacing [m]","fontsize",16)
ylabel ("Frequency", "fontsize",16)

% export histogram as svg-file
% set1_spacing.svg replace 1 by 2 or 3
print -dsvg set1_spacing.svg