% This file is part of the journal article "Semi-automated statistical 
% discontinuity analyses from scan-line data"
% Copyright (C) 2022 Christian Zangerl, Thomas Strauhal, Matthias Koppensteiner
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
% GNU General Public License for more details (http://www.gnu.org/licenses/).


% STEP VI trace length histogram
% plot semi-trace length histogram with fitted neg. exp. function
% as an example, it is calculated her for set 1
% load Octave statistics package
pkg load statistics

%-----------------input--------------------------------------------
% load data to plot
% load data file trace_termination_set1.mat, replace 1 by 2 or 3
load trace_termination_set1.mat

% define the histogram range and size in [m]
% e.g.[0.1:0.2:4] range from 0 to 4 m, class interval equals 0.2 m
delta=[0.1:0.2:4]

% -----------------------calculation--------------------------------
% calculation of semi-trace vector
semi_trace_above=trace_data(:,3);
semi_trace_below=trace_data(:,4);
semi_trace_all=[semi_trace_above;semi_trace_below]

% calculate values for the histogram
[Nx,xhist]=hist(semi_trace_all,delta)
int=delta(:,2)-delta(:,1)
ngem=sum(Nx)
fxgem=Nx/(ngem*int)
bar(xhist,Nx)

% fit negative exponential function to the histogram
% plot range - same as histogram, e.g. 0 to 4 m, interval 0.05 m
trace_x_axis=[0:0.05:4]

% mean of neg.exp.function
my=mean(semi_trace_all)
fun_neg_exp=(1/my)*exp(-trace_x_axis/my)

% plot histogram and neg.exp. function
bar(xhist,fxgem)
hold on
grid on
plot(trace_x_axis,fun_neg_exp,"linewidth",2)
% title ("Semi-trace-length","fontsize",16)
xlabel ("Semi-trace-length [m]","fontsize",16)
ylabel ("Frequency", "fontsize",16)

% export histogram as svg-file
% set1_semi_trace_length replace 1 by 2 or 3
print -dsvg set1_semi_trace_length.svg